// The direct drive shaft for the Y axis I installed has, for some reason,
// started trying to slip out of the oldham coupling after not doing
// it for years. So, since I've recently been making refrigerator magnet
// mounts from old disk drive magnets, this seems like a good opportunity
// to use one of the magnets to mount a stop on the solidoodle to keep
// the shaft from sliding sideways.

// thickness of the magnet parts
//
mag_tot_thick=7.68;
mag_big_thick=3.26;
mag_small_thick=(mag_tot_thick-mag_big_thick);

// size of magnet pieces
//
mag_len= 60.6;
mag_width=28.6;

// length of the 6mm shaft that sticks out the side of the solidoodle
//
shaft_len=35.3;
shaft_slop=4;

// base of outer cone radius
//
outer_base_radius=13;

// base of inner code radius
inner_base_radius=7;

// the shape of the big part of the magnet
//
module mag_big(h=10) {
   translate([-4.7,-10.9,0])
      linear_extrude(height=h) {
        import("big.svg", dpi=600);
      }
}

// the shape of the small part of the magnet (the actual magnetic bit)
//
module mag_small(h=10) {
   translate([-4.7,-10.9,0])
      linear_extrude(height=h) {
        import("small.svg", dpi=600);
      }
}

// m5 nut dimensions (plus slop)
//
m5nut_flat=7.85+0.2;
m5nut_thick=3.83+0.2;

// Utility routine for making hex nut shape
module hexnut(flat, thick) {
   intersection_for ( i = [0,60,120]) {
      rotate([0,0,i])
         translate([-(2*flat)/2, -flat/2, -thick])
            cube([2*flat,flat,thick]);
   }
}

//union() {
//   mag_big();
//   translate([0,0,-10])
//      mag_small(20);
//}

difference() {
   slop=4;
   ss=shaft_len+shaft_slop;
   union() {
      cylinder(r1=outer_base_radius,r2=10,h=ss, $fn=32);
      cylinder(r=(mag_width+10)/2,h=mag_tot_thick,$fn=32);
      translate([0,-(mag_width+10)/2,0])
         cube([mag_len+12,mag_width+10,mag_tot_thick]);
      translate([0,0,shaft_len+shaft_slop-1])
         difference() {
            cylinder(r=10,h=1+m5nut_thick*2,$fn=32);
            translate([0,0,m5nut_thick])
               hexnut(m5nut_flat,m5nut_thick+1);
            translate([0,0,-1])
               cylinder(r=5.2/2,h=50,$fn=32);
         }
   }
   translate([0,0,-0.1])
      cylinder(r1=inner_base_radius,r2=5,h=ss+0.2, $fn=32);
   translate([inner_base_radius,-mag_width/2,mag_small_thick])
      union() {
         mag_big(shaft_len+shaft_slop+50);
         translate([0,0,-(mag_small_thick+1)])
            mag_small(mag_small_thick+2);
      }
}
